#
# spec file for package perl-Email-MIME
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Email-MIME
Name:           perl-Email-MIME
Version:        1.954.0
Release:        1.6
# 1.954 -> normalize -> 1.954.0
%define cpan_version 1.954
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Easy MIME message handling
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RJ/RJBS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Email::Address::XS)
BuildRequires:  perl(Email::MIME::ContentType) >= 1.023
BuildRequires:  perl(Email::MIME::Encodings) >= 1.314
BuildRequires:  perl(Email::MessageID)
BuildRequires:  perl(Email::Simple) >= 2.212
BuildRequires:  perl(Email::Simple::Creator)
BuildRequires:  perl(Email::Simple::Header)
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.78
BuildRequires:  perl(MIME::Types) >= 1.13
BuildRequires:  perl(Module::Runtime)
BuildRequires:  perl(Test::More) >= 0.96
BuildRequires:  perl(parent)
Requires:       perl(Email::Address::XS)
Requires:       perl(Email::MIME::ContentType) >= 1.023
Requires:       perl(Email::MIME::Encodings) >= 1.314
Requires:       perl(Email::MessageID)
Requires:       perl(Email::Simple) >= 2.212
Requires:       perl(Email::Simple::Creator)
Requires:       perl(Email::Simple::Header)
Requires:       perl(MIME::Types) >= 1.13
Requires:       perl(Module::Runtime)
Requires:       perl(parent)
Provides:       perl(Email::MIME) = %{version}
Provides:       perl(Email::MIME::Creator) = %{version}
Provides:       perl(Email::MIME::Encode) = %{version}
Provides:       perl(Email::MIME::Header) = %{version}
Provides:       perl(Email::MIME::Header::AddressList) = %{version}
Provides:       perl(Email::MIME::Modifier) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
This is an extension of the Email::Simple module, to handle MIME encoded
messages. It takes a message as a string, splits it up into its constituent
parts, and allows you access to various parts of the message. Headers are
decoded from MIME encoding.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Fri May  3 2024 Tina Müller <timueller+perl@suse.de>
- updated to 1.954
  see /usr/share/doc/packages/perl-Email-MIME/Changes
  1.954     2024-05-02 17:12:30-04:00 America/New_York
  - Fix for CVE-2024-4140: An excessive memory use issue (CWE-770)
    exists in Email-MIME, before version 1.954, which can cause denial of
    service when parsing multipart MIME messages.  The fix is the new
    $MAX_PARTS configuration limits how many parts we will consider
    parsing.  The default $MAX_PARTS is 100.
* Mon Jan  9 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.953
  see /usr/share/doc/packages/perl-Email-MIME/Changes
  1.953     2023-01-08 19:02:24-05:00 America/New_York
  - as promised, this release no longer works on v5.8; in fact, due to
    some upstream libraries, it hasn't in some time
  - documentation has been cleaned up to stop referencing long-dead other
    libraries or methods
  - some small code changes to benefit from v5.10 and v5.12 improvements
* Wed Dec 15 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.952
  see /usr/share/doc/packages/perl-Email-MIME/Changes
  1.952     2021-12-14 09:57:27-05:00 America/New_York
  - exactly 1.951, except will install on 5.8.8
  - **ACHTUNG!**  Do not expect any future release to work on Perl v5.8
  1.951     2021-12-14 09:41:01-05:00 America/New_York
  - non-trial release of 1.950 changes
  1.950     2020-11-02 19:21:52-05:00 America/New_York (TRIAL RELEASE)
  - when computing filename, start from raw  Content-Disposition (thanks,
    Mishrakk)
  - avoid a potentially very slow regex in parsing (thanks, ivulfson)
* Mon May 25 2020 Tina Müller <timueller+perl@suse.de>
  updated to 1.949
  see /usr/share/doc/packages/perl-Email-MIME/Changes
  1.949     2020-05-24 10:25:36-04:00 America/New_York
  - no changes since trial release
  1.948     2020-05-09 14:57:17-04:00 America/New_York (TRIAL RELEASE)
  - fixes to handling of content-type parameters (thanks, dlucredativ and
    Pali Rohár)
  1.947     2020-05-09 14:30:06-04:00 America/New_York (TRIAL RELEASE)
  - add $Email::MIME::MAX_DEPTH and refuse to parse deeper than that many
    parts; current default: 10
* Sun Oct  7 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix autogenerated changes
* Wed Feb  7 2018 coolo@suse.com
- updated to 1.946
  see /usr/share/doc/packages/perl-Email-MIME/Changes
  1.946     2017-08-31 09:29:41-04:00 America/New_York
  - propagate encode_check to subparts (thanks, Michael McClimon)
  - use the new parse_content_disposition function in
    Email::MIME::ContentType (thanks, Pali Rohár)
  - fix a bug in AddressList handling (thanks, Pali Rohár)
  1.945     2017-07-25 14:17:32-04:00 America/New_York
  - fix encode-check.t to pass under legacy Test::Builder
  1.944     2017-07-25 12:38:41-04:00 America/New_York
  - non-trial release of header_as_obj changes
  - support for supplying a non-croak encode_check (thanks, Matthew
    Horsfall)
  1.943     2017-06-09 19:00:09-04:00 America/New_York (TRIAL RELEASE)
  - add Email::MIME::Header::AddressList and related support code
  1.942     2017-03-05 08:15:00-05:00 America/New_York (TRIAL RELEASE)
  - This adds ->header_as_obj to get MIME headers out of the header not
    as strings, but as objects.  The field-to-header mapping can be
    amended with the ->set_class_for_header method.
  1.941     2017-03-04 19:12:11-05:00 America/New_York (TRIAL RELEASE)
  - pointless mistake release
* Mon Feb 13 2017 coolo@suse.com
- updated to 1.940
  see /usr/share/doc/packages/perl-Email-MIME/Changes
  1.940     2017-01-29 10:33:45-05:00 America/New_York
  - no code changes since 1.939 trial release
  1.939     2017-01-14 14:58:44-05:00 America/New_York (TRIAL RELEASE)
  - do not decode MIME headers known to be never encoded (Pali Rohár)
  - ...and that includes the Downgraded-* headers (Pali Rohár)
  1.938     2017-01-01 20:03:38-05:00 America/New_York (TRIAL RELEASE)
  - numerous small fixes to header encoding (thanks, Pali Rohár)
    for more details see https://github.com/rjbs/Email-MIME/pull/32
  - When a single-part content type has been provided with multiple
    parts, the user is now warned that the type has been changed to
    multipart/mixed.  This helps catch typos like
    "mutlipart/alternative".
* Sun Feb  7 2016 coolo@suse.com
- updated to 1.937
  see /usr/share/doc/packages/perl-Email-MIME/Changes
  1.937     2016-01-28 13:31:06-05:00 America/New_York
  - eliminate memory leak in walk_parts (again, rjbs)
* Tue Sep 15 2015 coolo@suse.com
- updated to 1.936
  see /usr/share/doc/packages/perl-Email-MIME/Changes
  1.936     2015-09-10 22:46:29-04:00 America/New_York
  - no changes since 1.935, but a stable release
  1.935     2015-08-31 16:47:46-04:00 America/New_York (TRIAL RELEASE)
  - do not remove too many newlines at the end (bug introduced in 1.926)
* Tue Aug  4 2015 coolo@suse.com
- updated to 1.934
  see /usr/share/doc/packages/perl-Email-MIME/Changes
  1.934     2015-08-01 20:33:57-04:00 America/New_York
  - fix debug_structure for multipart mail with only one subpart
* Wed Jul 29 2015 coolo@suse.com
- updated to 1.933
  see /usr/share/doc/packages/perl-Email-MIME/Changes
  1.933     2015-07-25 09:30:56-04:00 America/New_York
  - correct Email::Simple prereq
  - skip omitting content-type attributes with undef value
* Sat Jul 25 2015 coolo@suse.com
- updated to 1.932
  see /usr/share/doc/packages/perl-Email-MIME/Changes
  1.932     2015-07-24 22:24:06-04:00 America/New_York
  - stable release of previous trial releases
  - see v1.930 and v1.931, below
  1.931     2015-07-12 17:31:01-04:00 America/New_York (TRIAL RELEASE)
  - When doing parts_set to become single-part, do not lose the charset
    and set the mail to us-ascii.
    This is almost certainly a half measure, and this whole hunk of code
    should be improved.
  1.930     2015-03-25 22:58:42-04:00 America/New_York (TRIAL RELEASE)
  - rely on the new header_raw methods in new Email::Simple
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.929
  see /usr/share/doc/packages/perl-Email-MIME/Changes
  1.929     2015-02-17 09:31:35-05:00 America/New_York
  - try not to lose unrecognized content-type parameters
  - avoid copying the body content when not needed during construction
  1.928     2014-12-15 21:47:49-05:00 America/New_York
  - when converting from single part to multipart, drop
    Content-Transfer-Encoding and Content-Type's charset property
  - update subparts in walk_parts if stringification changes
  1.927     2014-12-04 10:19:58-05:00 America/New_York
  - add header_str_pairs; like header_pairs, but decoded
  - remove Email:MIME::Creator from synopsis
  1.926     2014-01-28 23:28:41-05:00 America/New_York
  - improve EOL processing with quoted-printable (thanks, Tomohiro
    Hosaka!)
  - avoid uninitialized warnings [rt.cpan.org #91707]
* Tue Nov 26 2013 coolo@suse.com
- updated to 1.925
    improve reliability of mail reconstruction during walk_parts (thanks,
    Tomohiro Hosaka!)
    update use of Email::MIME::ContentType to match new, fixed hash keys:
    type/subtype
    do not consider the part-ending CRLF part of the body
    avoid undefined warnings in debug_structure [rt.cpan.org #82388]
    (Thanks, Kurt Anderson)
    better error message when the given body is a ref but not a scalar
    ref [rt.cpan.org #59205]
    repackage, fixing version number
    repackage, remove PEP links, update bugtracker
    do not call parts_set during walk_parts unless the parts have
    actually changed
    When trying to decode a body, fall back to 7bit if the encoding is
    unknown.  Trying to create a new body in an unknown encoding is still
    forbidden.  This should make it easier to handle broken messages
    from "the internet."  ("Content-Transfer-Encoding: n"!?)
    try to encode headers based on the header structure, if it has one,
    rather than treating the header as a big string in all cases; thanks
    for this work go to Jesse Luehrs
    require a newer Email::Simple and cope with its improved line ending
    tweaks
* Thu Jun  9 2011 pascal.bleser@opensuse.org
- (cumulated) update to 1.908:
  * be more lenient with Content-Tranfser-Encoding values; stop at semicolons
  * fix a long-standing bug that prevent walk_parts from reaching all parts
  * eliminate memory leak in walk_parts (RT#59581)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sun Jul 11 2010 chris@computersalat.de
- fix build for noarch
  o removed .packlist/perllocal.pod
- added bcondwith test
* Sat Jun 19 2010 coolo@novell.com
- initial package created by cpanspec 1.78
